@@ -9,14 +9,12 @@ else:
     from typing import Literal
 
 import di
-import di.dependant
-from di.api.dependencies import DependantBase
 from di.api.providers import DependencyProvider
 
 T = typing.TypeVar("T")
 
 
-Scope = Literal["app", "connection", "endpoint"]
+Scope = Literal["app", "connection", "operation"]
 
 
 class Dependant(di.Dependant[typing.Any]):
@@ -25,17 +23,15 @@ class Dependant(di.Dependant[typing.Any]):
     def __init__(
         self,
         call: typing.Optional[DependencyProvider] = None,
-        scope: Scope = "endpoint",
-        share: bool = True,
+        scope: Scope = "operation",
+        use_cache: bool = True,
         wire: bool = True,
-        overrides: typing.Optional[
-            typing.Mapping[str, DependantBase[typing.Any]]
-        ] = None,
+        sync_to_thread: bool = False,
     ) -> None:
         super().__init__(
             call=call,
             scope=scope,
-            share=share,
+            use_cache=use_cache,
             wire=wire,
-            overrides=overrides,
+            sync_to_thread=sync_to_thread,
         )
